@@ -7,16 +7,10 @@ configuration.
 import logging as _logging
 
 from . import xdg
-from ._core import (
-    AbstractConfig,
-    Config,
-    MainType,
-    NewCommand,
-    Parser,
-    comma_list_or_file,
-    main_factory,
-    new_command_factory,
-)
+from ._config import AbstractConfig, Config
+from ._helpers import NewCommand, comma_list_or_file, new_command_factory
+from ._main import MainType, main_factory
+from ._parser import Parser, filter_cli_args
 
 
 __all__ = [
@@ -26,6 +20,7 @@ __all__ = [
     "NewCommand",
     "Parser",
     "comma_list_or_file",
+    "filter_cli_args",
     "main_factory",
     "new_command_factory",
     "xdg",
@@ -33,6 +28,6 @@ __all__ = [
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.1.3"
+__version__ = "0.2.0"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
